@@ -34,7 +34,9 @@ __all__ = (
     "ServerSideEncryptionTypesType",
     "StateType",
     "TypeType",
+    "DataExchangeServiceName",
     "ServiceName",
+    "ResourceServiceName",
     "PaginatorName",
 )
 
@@ -71,6 +73,7 @@ TypeType = Literal[
     "IMPORT_ASSET_FROM_API_GATEWAY_API",
     "IMPORT_ASSET_FROM_SIGNED_URL",
 ]
+DataExchangeServiceName = Literal["dataexchange"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -224,6 +227,7 @@ ServiceName = Literal[
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -372,6 +376,18 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
 PaginatorName = Literal[
     "list_data_set_revisions",
     "list_data_sets",
