@@ -112,6 +112,8 @@ __all__ = (
     "RevisionDestinationEntryTypeDef",
     "RevisionEntryTypeDef",
     "RevisionPublishedTypeDef",
+    "RevokeRevisionRequestRequestTypeDef",
+    "RevokeRevisionResponseTypeDef",
     "S3SnapshotAssetTypeDef",
     "SendApiAssetRequestRequestTypeDef",
     "SendApiAssetResponseTypeDef",
@@ -389,6 +391,9 @@ CreateRevisionResponseTypeDef = TypedDict(
         "SourceId": str,
         "Tags": Dict[str, str],
         "UpdatedAt": datetime,
+        "RevocationComment": str,
+        "Revoked": bool,
+        "RevokedAt": datetime,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
@@ -741,6 +746,9 @@ GetRevisionResponseTypeDef = TypedDict(
         "SourceId": str,
         "Tags": Dict[str, str],
         "UpdatedAt": datetime,
+        "RevocationComment": str,
+        "Revoked": bool,
+        "RevokedAt": datetime,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
@@ -1110,7 +1118,9 @@ RequestDetailsTypeDef = TypedDict(
         "ExportRevisionsToS3": "ExportRevisionsToS3RequestDetailsTypeDef",
         "ImportAssetFromSignedUrl": "ImportAssetFromSignedUrlRequestDetailsTypeDef",
         "ImportAssetsFromS3": "ImportAssetsFromS3RequestDetailsTypeDef",
-        "ImportAssetsFromRedshiftDataShares": "ImportAssetsFromRedshiftDataSharesRequestDetailsTypeDef",
+        "ImportAssetsFromRedshiftDataShares": (
+            "ImportAssetsFromRedshiftDataSharesRequestDetailsTypeDef"
+        ),
         "ImportAssetFromApiGatewayApi": "ImportAssetFromApiGatewayApiRequestDetailsTypeDef",
     },
     total=False,
@@ -1124,7 +1134,9 @@ ResponseDetailsTypeDef = TypedDict(
         "ExportRevisionsToS3": "ExportRevisionsToS3ResponseDetailsTypeDef",
         "ImportAssetFromSignedUrl": "ImportAssetFromSignedUrlResponseDetailsTypeDef",
         "ImportAssetsFromS3": "ImportAssetsFromS3ResponseDetailsTypeDef",
-        "ImportAssetsFromRedshiftDataShares": "ImportAssetsFromRedshiftDataSharesResponseDetailsTypeDef",
+        "ImportAssetsFromRedshiftDataShares": (
+            "ImportAssetsFromRedshiftDataSharesResponseDetailsTypeDef"
+        ),
         "ImportAssetFromApiGatewayApi": "ImportAssetFromApiGatewayApiResponseDetailsTypeDef",
     },
     total=False,
@@ -1179,6 +1191,9 @@ _OptionalRevisionEntryTypeDef = TypedDict(
         "Comment": str,
         "Finalized": bool,
         "SourceId": str,
+        "RevocationComment": str,
+        "Revoked": bool,
+        "RevokedAt": datetime,
     },
     total=False,
 )
@@ -1195,6 +1210,33 @@ RevisionPublishedTypeDef = TypedDict(
     },
 )
 
+RevokeRevisionRequestRequestTypeDef = TypedDict(
+    "RevokeRevisionRequestRequestTypeDef",
+    {
+        "DataSetId": str,
+        "RevisionId": str,
+        "RevocationComment": str,
+    },
+)
+
+RevokeRevisionResponseTypeDef = TypedDict(
+    "RevokeRevisionResponseTypeDef",
+    {
+        "Arn": str,
+        "Comment": str,
+        "CreatedAt": datetime,
+        "DataSetId": str,
+        "Finalized": bool,
+        "Id": str,
+        "SourceId": str,
+        "UpdatedAt": datetime,
+        "RevocationComment": str,
+        "Revoked": bool,
+        "RevokedAt": datetime,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 S3SnapshotAssetTypeDef = TypedDict(
     "S3SnapshotAssetTypeDef",
     {
@@ -1395,6 +1437,9 @@ UpdateRevisionResponseTypeDef = TypedDict(
         "Id": str,
         "SourceId": str,
         "UpdatedAt": datetime,
+        "RevocationComment": str,
+        "Revoked": bool,
+        "RevokedAt": datetime,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
